if select(2, UnitClass"player") ~= "HUNTER" then 
	Talented.altspells = nil
	return
end

function Talented:GetPetClass()
	local _, _, _, texture = GetTalentTabInfo(1, nil, true)
	return texture and texture:sub(10)
end
function Talented:PET_TALENT_POINTS_CHANGED()
	local class = self:GetPetClass()
	if not class then return end
	self:FixAlternatesTalents(class)
	local template = self.pet_current
	if not template then
		template = {
			pet = true,
			talentGroup = 1,
			name = "Current",
			
		}
		self.pet_current = template
	end
	template.class = class
	local info = self:UncompressSpellData(class)
	for tab, tree in ipairs(info) do
		template[tab] = {}
		for index in ipairs(tree) do
			local rank = select(5, GetTalentInfo(tab, index, nil, true))
			template[tab][index] = rank
		end
	end
	for _, view in self:IterateTalentViews(template) do
		view:Update()
	end
	if self.mode == "apply" then
		self:CheckTalentPointsApplied()
	end
end

function Talented:UNIT_PET(_, unit)
	if unit == "player" then
		self:PET_TALENT_POINTS_CHANGED()
	end
end

function Talented:InitializePet()
	self:RegisterEvent"UNIT_PET"
	self:RegisterEvent"PET_TALENT_POINTS_CHANGED"
	self:PET_TALENT_POINTS_CHANGED()
end


local function handle_ranks(...)
	local result = {}
	for i = 1, select("#", ...) do
		result[i] = tonumber((select(i, ...)))
	end
	return result
end

local function handle_alternates(...)
	local result = {}
	for i = 1, select("#", ...) do
		result[i] = handle_ranks(strsplit(";", (select(i, ...))))
	end
	return result
end

local function find_pet_talent_name(row, column)
	for i = 1, GetNumTalents(1, nil, true) do
		local n, _, r, c = GetTalentInfo(1, i, nil, true)
		if row == r and column == c then return n end
	end
	return nil
end

local function find_pet_talent_index(class, row, column)
	for index, info in ipairs(Talented:UncompressSpellData(class)[1]) do
		if info.row == row and info.column == column then
			return index
		end
	end
	return nil
end

local function handle_talent(class, row, column, data)
	row, column = tonumber(row), tonumber(column)
	return {
		class = class,
		row = row,
		column =column,
		index = assert(find_pet_talent_index(class, row, column)),
		alternates = handle_alternates(strsplit(",", data))
	}
end

local function handle_altspells(...)
	local result = {}
	for i = 1, select("#", ...) do
		result[i] = handle_talent(strsplit("|", (select(i, ...))))
	end
	return result
end

function Talented:FixAlternatesTalents(class)
	if not GetTalentInfo(1, 1, nil, true) then return end
	if type(Talented.altspells) == "string" then
		Talented.altspells = handle_altspells(strsplit("#", Talented.altspells))
		handle_altspells = nil
	end
	local data = Talented:UncompressSpellData(class)[1]
	for _, info in ipairs(self.altspells) do
		if info.class == class then
			local index = info.index
			local current = data[index]
			local name = assert(find_pet_talent_name(info.row, info.column))
			local replacement
			for i, alt in ipairs(info.alternates) do
				assert(#alt == #current.ranks)
				if GetSpellInfo(alt[1]) == name then
					replacement = alt
					break
				end
			end
			assert(replacement)
			for i, spell in ipairs(replacement) do
				current.ranks[i] = spell
			end
		end
	end
end